@@ -99,30 +99,31 @@ function paraselene_tag_set_event(dialog,tag){
 		paraselene_move_y=kmouse.clientY;
 		return false;
 	};
-	document.onmouseup=function(kmouse){
-		kmouse=paraselene_get_event(kmouse);
-		paraselene_mous_up_x=kmouse.clientX;
-		paraselene_mous_up_y=kmouse.clientY;
-		if(!paraselene_move_obj)	return true;
-		paraselene_move_obj=undefined;
-		return false;
-	};
-	document.onmousemove=function(kmouse){
-		if(!paraselene_move_obj)return true;
-		kmouse=paraselene_get_event(kmouse);
-		if(navigator.userAgent.indexOf("MSIE")!=-1){
-			if(kmouse.button==0){
-				paraselene_move_obj=undefined;
-				return true;
-			}
-		}
-		paraselene_tag_move(paraselene_move_obj,kmouse.clientX-paraselene_move_x,kmouse.clientY-paraselene_move_y);
-		paraselene_move_x=kmouse.clientX;
-		paraselene_move_y=kmouse.clientY;
-		return false;
-	};
 }
 
+document.onmouseup=function(kmouse){
+	kmouse=paraselene_get_event(kmouse);
+	paraselene_mous_up_x=kmouse.clientX;
+	paraselene_mous_up_y=kmouse.clientY;
+	if(!paraselene_move_obj)	return true;
+	paraselene_move_obj=undefined;
+	return false;
+};
+document.onmousemove=function(kmouse){
+	if(!paraselene_move_obj)return true;
+	kmouse=paraselene_get_event(kmouse);
+	if(navigator.userAgent.indexOf("MSIE")!=-1){
+		if(kmouse.button==0){
+			paraselene_move_obj=undefined;
+			return true;
+		}
+	}
+	paraselene_tag_move(paraselene_move_obj,kmouse.clientX-paraselene_move_x,kmouse.clientY-paraselene_move_y);
+	paraselene_move_x=kmouse.clientX;
+	paraselene_move_y=kmouse.clientY;
+	return false;
+};
+
 function ParaseleneAjax(key,callback,msec,comet_f){
 	this.inteval=msec;
 	this.callback=callback;
@@ -169,7 +170,19 @@ function paraselene_get_http(){
 	return obj;
 }
 
-var paraselene_json_url='paraselene.json.na?key=';
+var paraselene_json_cnt=0;
+
+function paraselene_make_dummy(){
+	var p=new Date().getTime().toString(36) + paraselene_json_cnt.toString(36);
+	paraselene_json_cnt++;
+	return p;
+}
+
+function paraselene_json_url_gaet(p){
+	var url="paraselene.json.na?paraselene_dmy="+paraselene_make_dummy();
+	url=url+"&key="+p;
+	return url;
+}
 
 ParaseleneAjax.prototype={
 	http_access:function(){
@@ -182,7 +195,7 @@ ParaseleneAjax.prototype={
 			};
 		}(paraselene_holder[this.no]);
 		var param=this.key+"&comet="+this.comet_f;
-		this.http.open('GET',paraselene_json_url+param,true);
+		this.http.open('GET',paraselene_json_url_gaet(param),true);
 		this.http.send('');
 	}
 };
@@ -374,10 +387,18 @@ function paraselene_action(obj){
 			resize_f=true;
 			continue;
 		}
-		var update_tag=val.tag;
-		var target=paraselene_get_id(update_tag.id);
-		if(target)	target.innerHTML=update_tag.body;
-		resize_f=true;
+		if(val.tag){
+			var update_tag=val.tag;
+			var target=paraselene_get_id(update_tag.id);
+			if(target)	target.innerHTML=update_tag.body;
+			resize_f=true;
+			continue;
+		}
+		if(val.exec){
+			var exec=val.exec;
+			eval(exec.cmd);
+			continue;
+		}
 	}
 }
 
@@ -421,7 +442,12 @@ function paraselene_get(o,url,key){
 }
 
 function paraselene_agency_a(o,key){
-	if(!paraselene_get(o,o.getAttribute('href'),key))	return true;
+	var href=o.getAttribute("href").split("?");
+	href[0]=href[0]+"?paraselene_a_dummy="+paraselene_make_dummy();
+	if(href[1]){
+		href[0]=href[0]+"&"+href[1];
+	}
+	if(!paraselene_get(o,href[0],key))	return true;
 	return false;
 }
 
@@ -435,6 +461,7 @@ function paraselene_agency_form(o,key){
 	if(!url)	return true;
 	o.target="paraseleneDragonsTail";
 	o.paraselene_form_ajax.value=key;
+	o.paraselene_form_dummy.value=paraselene_make_dummy();
 	paraselene_called_form=o;
 	return true;
 }
@@ -445,7 +472,7 @@ function paraselene_form_ok(key){
 	paraselene_called_form.paraselene_form_ajax.value=-1;
 	var svr=paraselene_get_http();
 	document.body.style.cursor="wait";
-	svr.open('GET',paraselene_json_url+key,false);
+	svr.open('GET',paraselene_json_url_gaet(key),false);
 	svr.send('');
 	if(svr.status!=200){
 		paraselene_error_page(svr);
