@@ -73,6 +73,12 @@ public class FormJson extends #1.SuperPage {
 	public boolean isAllowHistoryAdd() { return false; }
 	public String getCharset() { return "UTF-8"; }
 
+	/**
+	 * キャッシュ禁止指定。
+	 * @return true:ブラウザキャッシュを禁止します。
+	 */
+	public boolean isNoCache() { return true; }
+
 	/**
 	 * 初回outputの呼び出しメイン処理。
 	 * @param req リクエスト内容。
