@@ -731,6 +731,7 @@ public abstract class Page implements Serializable {
 		if ( name != null ) {
 			if ( Form.FORM_ID.equals( name ) )	return;
 			if ( Form.FORM_AJAX.equals( name ) )	return;
+			if ( Form.FORM_DUMMY.equals( name ) )	return;
 		}
 		nameTagSingle( tag );
 		int	cnt = tag.getHTMLPartCount();
@@ -1061,7 +1062,7 @@ public abstract class Page implements Serializable {
 				head.addHTMLPart( script );
 
 				Tag[]	div = new Tag[] { new Tag( "div", false ), new Tag( "div", false ) };
-				div[0].include( body );
+				div[0].include( body, true );
 				Tag eclipse = new Tag( "div", false );
 				eclipse.setAttribute(
 					new Attribute( "id", AJAX_BLACK_ID )
