@@ -15,6 +15,7 @@ public class PostBack implements Serializable {
 	public Open		open = null;
 	public Close	close = null;
 	public TagData	tag = null;
+	public Exec		exec = null;
 
 	protected PostBack(){}
 
@@ -33,5 +34,9 @@ public class PostBack implements Serializable {
 	public PostBack( TagData t ) {
 		tag = t;
 	}
+
+	public PostBack( Exec e ) {
+		exec = e;
+	}
 }
 
