@@ -82,6 +82,12 @@ public enum Param {
 	HTML_ROOT( "-html",
 		"読み込むhtmlの配置ディレクトリ。その直下より再帰読み込みします。",
 		true, true ),
+	WEB_APP( "-web_application",
+		"true を指定すると、Web アプリケーション構築用のスケルトンソースを出力します。\n" +
+		"false を指定すると、logic と view パッケージのみ生成します。\n" +
+		"共通コンポーネントの部品を出力したい場合等に false を指定します。\n" +
+		"false を指定した場合、URI の解決を一切行いません。",
+		false, true, "true" ),
 	OUT_PATH( "-out",
 		"出力ディレクトリ。スケルトンソースファイルや定義ファイルの出力先です。\n" +
 		"出力ディレクトリが無ければ作成します。\n" +
@@ -147,7 +153,8 @@ public enum Param {
 		false, true ),
 	OUT_ENCODE( "-output_encode",
 		"実行時の文字コード。\n" +
-		"実行時、ブラウザにはこの文字コードで出力されます。",
+		"実行時、ブラウザにはこの文字コードで出力されます。\n" +
+		"実行中に変更も可能です。",
 		false, true, "UTF-8" ),
 	SOURCE_ENCODE( "-source_encode",
 		"生成するスケルトンソースファイルの出力文字コード。",
@@ -349,6 +356,13 @@ public enum Param {
 			System.err.println( OUT_ENCODE.key + " の指定が不正です" );
 			System.exit( 1 );
 		}
+		try {
+			Boolean.valueOf( WEB_APP.get() );
+		}
+		catch(Exception e) {
+			System.err.println( WEB_APP.key + " の指定が不正です" );
+			System.exit( 1 );
+		}
 		try {
 			Boolean.valueOf( CLEAR.get() );
 		}
