@@ -93,7 +93,7 @@ class TagSource extends Tag implements Source {
 			buf = buf.append( "new Style(Property.create(" );
 			buf = buf.append( Make.escape( val ) );
 			buf = buf.append( "," );
-			buf = buf.append( Make.escape( ((PrePage)embed).getParsingCharset() ) );
+			buf = buf.append( Make.escape( ((PrePage)getAssignedTag().getAssignedPage()).getParsingCharset() ) );
 			buf = buf.append( ")))" );
 			return buf.toString();
 		}
