@@ -130,6 +130,18 @@ class CloseOutput extends OutputCall {
 	}
 }
 
+class ScriptOutput extends OutputCall {
+	ScriptOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		super( nk, lp, fw, r, sd );
+	}
+	void call() throws Throwable {}
+	PostBack[] make() throws Exception {
+		JavaScript	js = (JavaScript)forward;
+		Option.trace( "%s to JavaScript JSON", js.cmd );
+		return new PostBack[] { new PostBack( new Exec( js.cmd ) ) };
+	}
+}
+
 class LocationOutput extends OutputCall {
 	LocationOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		super( nk, lp, fw, r, sd );
@@ -171,7 +183,11 @@ class OutputHolder {
 		}
 		if ( lp.isAjax() ) {
 			for ( int i = 0; i < forward.length; i++ ) {
-				if ( forward[i] instanceof Closure ) {
+				if ( forward[i] instanceof JavaScript ){
+					Option.trace( "new ScriptOutput <- %s", forward[i] );
+					opc[i] = new ScriptOutput( nk, lp, forward[i], r, sd );
+				}
+				else if ( forward[i] instanceof Closure ) {
 					Closure	c = (Closure)forward[i];
 					if ( c.close_page.getPopupType() == null ) {
 						Option.trace( "new LocationOutput <- %s", forward[i] );
