@@ -529,6 +529,7 @@ public abstract class Supervisor extends HttpServlet {
 					Page	ajax_page = getPageFactory().getPage( PAGE_ID_JSON );
 					ajax_page.output( null, req );
 					write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
+					Option.trace( "JSON postback %s", key );
 					return;
 				}
 			}
@@ -541,6 +542,7 @@ public abstract class Supervisor extends HttpServlet {
 					Page	ajax_page = getPageFactory().getPage( PAGE_ID_FORM_JSON );
 					ajax_page.output( last_page, req );
 					write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
+					Option.trace( "FORM postback %s", key );
 					return;
 				}
 			}
@@ -657,7 +659,7 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			else if ( next_page.isNoCache() ) {
 				res.addHeader( "Pragma", "no-cache" );
-				res.addHeader( "Cache-Control", "no-cache, no-store" );
+				res.addHeader( "Cache-Control", "no-cache, no-store, must-revalidate" );
 			}
 			if ( fw != null ) {
 				int	ck_cnt = fw.out_cookie.size();
@@ -827,6 +829,7 @@ public abstract class Supervisor extends HttpServlet {
 			return onErrorDebug( e, request, res, 422 );
 		}
 		req.setParam( method, request, this );
+		Option.trace( "client access %s", req.getURI() );
 		holder.search_engine = req.judgeSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
 		holder.request = req;
 
