@@ -32,23 +32,35 @@ class FormSeq {
 public class Form extends Tag {
 	private static final long serialVersionUID = 2L;
 	/**
-	 * 予約済みHIDDEN項目のname。paraselene$form
+	 * 予約済みHIDDEN項目のname。
 	 */
 	public static final String FORM_ID = "paraselene$form$id";
 	/**
-	 * 予約済みHIDDEN項目のname。paraselene$ajax
+	 * 予約済みHIDDEN項目のname。
 	 */
 	public static final String FORM_AJAX = "paraselene_form_ajax";
+	/**
+	 * 予約済みHIDDEN項目のname。
+	 */
+	public static final String FORM_DUMMY = "paraselene_form_dummy";
 	/**
 	 * マルチパート。
 	 */
 	public static final String MULTI_PART = "multipart/form-data";
 
+	private static HashMap<String, String>	skip_name = new HashMap<String, String>();
+
 	private static FormSeq	form_seq = new FormSeq();
 	private	String	seq;
 	private HashMap<String, HashMap<String,Control>>	control = new HashMap<String, HashMap<String,Control>>();
 	private boolean fixed_f = false;
 
+	static {
+		skip_name.put( FORM_ID, FORM_ID );
+		skip_name.put( FORM_AJAX, FORM_AJAX );
+		skip_name.put( FORM_DUMMY, FORM_DUMMY );
+	}
+
 	/**
 	 * コントロールインスタンスが存在するか？
 	 * @param cont 検証するインスタンス。
@@ -63,6 +75,8 @@ public class Form extends Tag {
 		return map.get( name ) == cont;
 	}
 
+	private Input	dummy = Input.createHidden( FORM_DUMMY, "-1" );
+
 	/**
 	 * コンストラクタ。
 	 */
@@ -71,7 +85,8 @@ public class Form extends Tag {
 		seq = form_seq.getSeq();
 		Input[]	id = new Input[] {
 			Input.createHidden( FORM_ID, seq ),
-			Input.createHidden( FORM_AJAX, "-1" )
+			Input.createHidden( FORM_AJAX, "-1" ),
+			dummy
 		};
 		addHTMLPart( id );
 		fixed_f = true;
@@ -103,6 +118,7 @@ public class Form extends Tag {
 				}
 			}
 		}
+		dummy.setValueString( form_seq.getSeq() );
 		super.write( w, mode );
 	}
 
@@ -236,6 +252,7 @@ public class Form extends Tag {
 		for ( int i = 0; i < cont.length; i++ ) {
 			String	name = cont[i].getNameAttribute();
 			if ( name == null )	continue;
+			if ( skip_name.get( name ) != null )	continue;
 			CheckBox	cbox = null;
 			if ( cont[i] instanceof CheckBox ) {
 				cbox = (CheckBox)cont[i];
